@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from cltoolbox import command, main
 
 
@@ -8,8 +9,8 @@ def cmd(foo, bar):
     And here the description of this useless command.
 
     :param foo: Well, the first arg.
-    :param bar: Obviously the second arg. Nonsense."""
-
+    :param bar: Obviously the second arg. Nonsense.
+    """
     print(foo, bar)
 
 
