@@ -9,8 +9,8 @@ def pow(a, b, mod=None):
 
     :param float a: The base.
     :param float b: The exponent.
-    :param int mod: Modulus."""
-
+    :param int mod: Modulus.
+    """
     if mod is not None:
         print((a**b) % mod)
     else:
