@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from cltoolbox import arg, command, main
 
 
@@ -11,8 +12,8 @@ def push(repository, all=False, dry_run=False, force=False, thin=False):
     :param all: Push all refs.
     :param dry_run: Dry run.
     :param force: Force updates.
-    :param thin: Use thin pack."""
-
+    :param thin: Use thin pack.
+    """
     print(
         f"Pushing to {repository}. All: {all}, dry run: {dry_run}, force: {force}, thin: {thin}"
     )
